async fn process_block_chunk(
chunk: &str,
system_message: &APIMessage,
app_config: &ApplicationConfiguration,
task_lm: &TaskLMSpec,
) -> ChatbotResult<String>Expand description
Process a subset of blocks in a single LLM request
async fn process_block_chunk(
chunk: &str,
system_message: &APIMessage,
app_config: &ApplicationConfiguration,
task_lm: &TaskLMSpec,
) -> ChatbotResult<String>Process a subset of blocks in a single LLM request